==> jc-1.4.0.tar.gz: polyglot/util/Pair.h <==
// public class polyglot.util.Pair

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 98b787b92ac6a3b9 polyglot_util_Pair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_Pair_H_
#define _JC_polyglot_util_Pair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_polyglot_util_Pair$sub_refs	_jc_polyglot_util_Pair$sub_refs;
typedef struct _jc_polyglot_util_Pair$sub_nonrefs	_jc_polyglot_util_Pair$sub_nonrefs;
typedef struct _jc_polyglot_util_Pair$refs	_jc_polyglot_util_Pair$refs;
typedef struct _jc_polyglot_util_Pair$nonrefs	_jc_polyglot_util_Pair$nonrefs;
typedef struct _jc_polyglot_util_Pair$object	_jc_polyglot_util_Pair$object;

typedef const struct _jc_polyglot_util_Pair$vmethods	_jc_polyglot_util_Pair$vmethods;
typedef const struct _jc_polyglot_util_Pair$vtable	_jc_polyglot_util_Pair$vtable;
typedef const struct _jc_polyglot_util_Pair$vtype	_jc_polyglot_util_Pair$vtype;

// Constructors
extern void _jc_polyglot_util_Pair$method$_init$1b34a4ef37055d19(_jc_env *, struct _jc_polyglot_util_Pair$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_Pair$method$part1$0c1e939f4cba35c8(_jc_env *, struct _jc_polyglot_util_Pair$object *);
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_Pair$method$part2$7912c7411ed9b452(_jc_env *, struct _jc_polyglot_util_Pair$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_Pair$method_info$part1$0c1e939f4cba35c8;
extern _jc_method _jc_polyglot_util_Pair$method_info$part2$7912c7411ed9b452;

// Virtual methods structure
struct _jc_polyglot_util_Pair$vmethods {
	struct _jc_java_lang_Object$object	*(*part1$0c1e939f4cba35c8)(_jc_env *, struct _jc_polyglot_util_Pair$object *);
	struct _jc_java_lang_Object$object	*(*part2$7912c7411ed9b452)(_jc_env *, struct _jc_polyglot_util_Pair$object *);
};

// Vtable
struct _jc_polyglot_util_Pair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Pair$vmethods	polyglot_util_Pair;
};

// Vtype
struct _jc_polyglot_util_Pair$vtype {
	_jc_type			type;
	_jc_polyglot_util_Pair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Pair$sub_refs {
	struct _jc_java_lang_Object$object	*part1;
	struct _jc_java_lang_Object$object	*part2;
};

// Reference instance fields (object)
struct _jc_polyglot_util_Pair$refs {
    _jc_polyglot_util_Pair$sub_refs	polyglot_util_Pair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Pair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Pair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Pair$sub_nonrefs	polyglot_util_Pair;
};

// Object instance structure
struct _jc_polyglot_util_Pair$object {
	_jc_polyglot_util_Pair$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Pair$vtype	*vtype;
	_jc_polyglot_util_Pair$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Pair$vtype _jc_polyglot_util_Pair$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Pair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Pair$class_object;

#endif	/* _JC_polyglot_util_Pair_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/Pair.h <==
// public class polyglot.util.Pair

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 98b787b92ac6a3b9 polyglot_util_Pair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_Pair_H_
#define _JC_polyglot_util_Pair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_polyglot_util_Pair$sub_refs	_jc_polyglot_util_Pair$sub_refs;
typedef struct _jc_polyglot_util_Pair$sub_nonrefs	_jc_polyglot_util_Pair$sub_nonrefs;
typedef struct _jc_polyglot_util_Pair$refs	_jc_polyglot_util_Pair$refs;
typedef struct _jc_polyglot_util_Pair$nonrefs	_jc_polyglot_util_Pair$nonrefs;
typedef struct _jc_polyglot_util_Pair$object	_jc_polyglot_util_Pair$object;

typedef const struct _jc_polyglot_util_Pair$vmethods	_jc_polyglot_util_Pair$vmethods;
typedef const struct _jc_polyglot_util_Pair$vtable	_jc_polyglot_util_Pair$vtable;
typedef const struct _jc_polyglot_util_Pair$vtype	_jc_polyglot_util_Pair$vtype;

// Constructors
extern void _jc_polyglot_util_Pair$method$_init$1b34a4ef37055d19(_jc_env *, struct _jc_polyglot_util_Pair$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_Pair$method$part1$0c1e939f4cba35c8(_jc_env *, struct _jc_polyglot_util_Pair$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_Pair$method$part2$7912c7411ed9b452(_jc_env *, struct _jc_polyglot_util_Pair$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_Pair$method_info$part1$0c1e939f4cba35c8;
extern _jc_method _jc_polyglot_util_Pair$method_info$part2$7912c7411ed9b452;

// Virtual methods structure
struct _jc_polyglot_util_Pair$vmethods {
	struct _jc_java_lang_Object$object	*(*part1$0c1e939f4cba35c8)(_jc_env *, struct _jc_polyglot_util_Pair$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*part2$7912c7411ed9b452)(_jc_env *, struct _jc_polyglot_util_Pair$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_Pair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Pair$vmethods	polyglot_util_Pair;
};

// Vtype
struct _jc_polyglot_util_Pair$vtype {
	_jc_type			type;
	_jc_polyglot_util_Pair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Pair$sub_refs {
	struct _jc_java_lang_Object$object	*part1;
	struct _jc_java_lang_Object$object	*part2;
};

// Reference instance fields (object)
struct _jc_polyglot_util_Pair$refs {
    _jc_polyglot_util_Pair$sub_refs	polyglot_util_Pair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Pair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Pair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Pair$sub_nonrefs	polyglot_util_Pair;
};

// Object instance structure
struct _jc_polyglot_util_Pair$object {
	_jc_polyglot_util_Pair$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Pair$vtype	*vtype;
	_jc_polyglot_util_Pair$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Pair$vtype _jc_polyglot_util_Pair$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Pair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Pair$class_object;

#endif	/* _JC_polyglot_util_Pair_H_ */
